@@ -447,27 +447,27 @@ assay_facets: Facets = {
     "ELISA": {"Data": FacetConfig(["/elisa/assay.xlsx"])},
     "ctDNA": {
         "Demultiplexed Source BAMs": FacetConfig(
-            ["/ctdna/demultiplexed.bam", "/ctdna/demultiplexed.bam.bai"],
+            ["/ctdna/demultiplexed.bam"],
             "Demultiplexed BAM files (and indexes) generated from circulating tumor DNA.",
         ),
         "Genome-wide Plots": FacetConfig(
-            ["/ctdna_analysis/genome-wide_plots.pdf"],
+            ["/ctdna/genome-wide_plots.pdf"],
             "Plots showing Copy Number Alteration (CNA) across the whole genome for all solutions generated by ichorCNA.",
         ),
         "Bias / QC Plots": FacetConfig(
-            ["/ctdna_analysis/bias_qc_plots.pdf"],
+            ["/ctdna/bias_qc_plots.pdf"],
             "Plots showing readcount corrections applied by ichorCNA for GC bias and Mappability bias.",
         ),
         "Optimal Solutions": FacetConfig(
-            ["/ctdna_analysis/optimal_solution.zip"],
+            ["/ctdna/optimal_solution.zip"],
             "The optimal solution as calculated by ichorCNA.",
         ),
         "Other Solutions": FacetConfig(
-            ["/ctdna_analysis/other_solutions.zip"],
+            ["/ctdna/other_solutions.zip"],
             "Other possible solutions also calculated by ichorCNA.",
         ),
         "Batch-level Summary Plots": FacetConfig(
-            ["/ctdna_analysis/summary_plots.pdf"],
+            ["/ctdna/summary_plots.pdf"],
             "Plots showing Copy Number Alteration (CNA) across the whole genome for each sample for the top 2 solutions generated by ichorCNA.",
         ),
     },
@@ -485,7 +485,7 @@ assay_facets: Facets = {
             "Operational taxonomic unit matrix.",
         ),
         "Batch-level Summary Plots": FacetConfig(
-            ["/microbiome_analysis/summary.pdf"],
+            ["/microbiome/summary.pdf"],
             "Plots showing analysis summary for microbiome.",
         ),
     },
@@ -524,14 +524,6 @@ analysis_ready_facets = {
     "WES Assay": FacetConfig(["maf|combined maf"]),
     "TCR": FacetConfig(["/tcr_analysis/report_trial.tar.gz"]),
     "mIF": FacetConfig(["/mif/roi_/cell_seg_data.txt"]),
-    "ctDNA": FacetConfig(
-        ["/ctdna_analysis/summary_plots.pdf"],
-        "Plots showing Copy Number Alteration (CNA) across the whole genome for each sample for the top 2 solutions generated by ichorCNA.",
-    ),
-    "Microbiome": FacetConfig(
-        ["/microbiome_analysis/summary.pdf"],
-        "Plots showing analysis summary for microbiome.",
-    ),
 }
 
 facets_dict: Dict[str, Facets] = {
